#
# spec file for package python-jupyter_client-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# PDF documentation currently broken
%bcond_with pdf
%bcond_without html
%bcond_without tests
Name:           python-jupyter_client-doc
Version:        5.2.3
Release:        2.12
Summary:        Documentation for python-jupyter_client
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jupyter/jupyter_client
Source:         https://files.pythonhosted.org/packages/source/j/jupyter_client/jupyter_client-%{version}.tar.gz
BuildRequires:  %{python_module jupyter_client}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       %{name}-html = %{version}
Provides:       %{name}-pdf = %{version}
Obsoletes:      %{name}-html < %{version}
Obsoletes:      %{name}-pdf < %{version}
Provides:       python-jupyter_client-doc = %{version}
BuildArch:      noarch
%if %{with tests}
# Test Requirements
BuildRequires:  %{python_module backcall}
BuildRequires:  %{python_module jupyter_ipykernel}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pytest}
# Python 2.7 test requirements
BuildRequires:  python-mock
%endif
# Documentation requirements
%if %{with pdf} || %{with html}
BuildRequires:  %{python_module sphinxcontrib-github-alt}
BuildRequires:  python3-Sphinx
%endif
%if %{with pdf}
BuildRequires:  python3-Sphinx-latex
%endif

%description
Documentation and help files for python-jupyter_client.

%prep
%setup -q -n jupyter_client-%{version}

%build
# Build the documentation
pushd docs
%if %{with html}
make %{?_smp_mflags} html
rm -rf build/html/.buildinfo
%endif
%if %{with pdf}
make %{?_smp_mflags} latexpdf
%endif
popd

%install
mkdir -p %{buildroot}%{_docdir}/python-jupyter_client

%if %{with pdf}
cp docs/_build/latex/jupyter_core.pdf %{buildroot}%{_docdir}/python-jupyter_client/
%endif

%if %{with html}
cp -r docs/_build/html %{buildroot}%{_docdir}/python-jupyter_client/
%endif

%fdupes %{buildroot}%{_docdir}/python-jupyter_client/

%if %{with tests}
%check
pushd jupyter_client/tests
%python_expand py.test-%{$python_bin_suffix}
popd
%endif

%files
%license COPYING.md
%{_docdir}/python-jupyter_client/

%changelog
* Thu Apr 12 2018 arun@gmx.de
- specfile:
  * add requirement for python-backcall
  * fix 'provides' syntax
- update to version 5.2.3:
  * Fix hang on close in :class:`.ThreadedKernelClient` (used in
    QtConsole) when using tornado with asyncio (default behavior of
    tornado 5, see :ghpull:`352`).
  * Fix errors when using deprecated :attr:`.KernelManager.kernel_cmd`
    (:ghpull:`343`, :ghpull:`344`).
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update dependencies.
- Add fix_COPY_THRESHOLD.patch
  Fixes tests for pyzmq < 17
  See: https://github.com/jupyter/jupyter_client/pull/349
* Sat Feb 10 2018 arun@gmx.de
- update to version 5.2.2:
  * Fix :meth:`.KernelSpecManager.get_all_specs` method in subclasses
    that only override :meth:`.KernelSpecManager.find_kernel_specs`
    and :meth:`.KernelSpecManager.get_kernel_spec`. See :ghissue:`338`
    and :ghpull:`339`.
  * Eliminate occasional error messages during process exit
    (:ghpull:`336`).
  * Improve error message when attempting to bind on invalid address
    (:ghpull:`330`).
  * Add missing direct dependency on tornado (:ghpull:`323`).
* Thu Jan  4 2018 arun@gmx.de
- specfile:
  * update copyright year
  * require python-spinxcontrib-github-alt
- update to version 5.2.1:
  * Add parenthesis to conditional pytest requirement to work around a
    bug in the wheel package, that generate a .whl which otherwise
    always depends on pytest see :ghissue:`324` and :ghpull:`325`
* Thu Dec 21 2017 arun@gmx.de
- update to version 5.2.0:
  * Define Jupyter protocol version 5.3:
    + Kernels can now opt to be interrupted by a message sent on the
    control channel instead of a system signal. See
    :ref:`kernelspecs` and :ref:`msging_interrupt` (:ghpull:`294`).
  * New jupyter kernel command to launch an installed kernel by name
    (:ghpull:`240`).
  * Kernelspecs where the command starts with e.g. python3 or
    python3.6—matching the version jupyter_client is running on—are
    now launched with the same Python executable as the launching
    process (:ghpull:`306`). This extends the special handling of
    python added in 5.0.
  * Command line arguments specified by a kernelspec can now include
    {resource_dir}, which will be substituted with the kernelspec
    resource directory path when the kernel is launched
    (:ghpull:`289`).
  * Kernelspecs now have an optional metadata field to hold arbitrary
    metadata about kernels—see :ref:`kernelspecs` (:ghpull:`274`).
  * Make the KernelRestarter class used by a KernelManager
    configurable (:ghpull:`290`).
  * When killing a kernel on Unix, kill its process group
    (:ghpull:`314`).
  * If a kernel dies soon after starting, reassign random ports before
    restarting it, in case one of the previously chosen ports has been
    bound by another process (:ghpull:`279`).
  * Avoid unnecessary filesystem operations when finding a kernelspec
    with :meth:`.KernelSpecManager.get_kernel_spec` (:ghpull:`311`).
  * :meth:`.KernelSpecManager.get_all_specs` will no longer raise an
    exception on encountering an invalid kernel.json file. It will
    raise a warning and continue (:ghpull:`310`).
  * Check for non-contiguous buffers before trying to send them
    through ZMQ (:ghpull:`258`).
  * Compatibility with upcoming Tornado version 5.0 (:ghpull:`304`).
  * Simplify setup code by always using setuptools (:ghpull:`284`).
  * Soften warnings when setting the sticky bit on runtime files fails
    (:ghpull:`286`).
  * Various corrections and improvements to documentation.
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to version 5.1
  * Define Jupyter protocol version 5.2,
    resolving ambiguity of ``cursor_pos`` field in the presence
    of unicode surrogate pairs.
  * Add :meth:`Session.clone` for making a copy of a Session object
    without sharing the digest history.
    Reusing a single Session object to connect multiple sockets
    to the same IOPub peer can cause digest collisions.
  * Avoid global references preventing garbage collection of background threads.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Update to 5.0.1
  * Update internal protocol version number to 5.1,
    which should have been done in 5.0.0.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 5.0.0
  + New features:
  * Introduce :command:`jupyter run` command for running scripts with a kernel, for instance::
    jupyter run --kernel python3 myscript.py
  * New method :meth:`.BlockingKernelClient.execute_interactive`
    for running code and capturing or redisplaying its output.
  * New ``KernelManager.shutdown_wait_time`` configurable for adjusting the time
    for a kernel manager to wait after politely requesting shutdown
    before it resorts to forceful termination.
  + Fixes:
  * Set sticky bit on connection-file directory to avoid getting cleaned up.
  * :func:`jupyter_client.launcher.launch_kernel` passes through additional options to the underlying Popen,
    matching :meth:`KernelManager.start_kernel`.
  * Check types of ``buffers`` argument in :meth:`.Session.send`,
    so that TypeErrors are raised immediately,
    rather than in the eventloop.
  + Changes:
  * In kernelspecs, if the executable is the string ``python`` (as opposed to an absolute path),
    ``sys.executable`` will be used rather than resolving ``python`` on PATH.
    This should enable Python-based kernels to install kernelspecs as part of wheels.
  * kernelspec names are now validated.
    They should only include ascii letters and numbers, plus period, hyphen, and underscore.
  + Backward-incompatible changes:
  * :py:class:`.datetime` objects returned in parsed messages are now always timezone-aware.
    Timestamps in messages without timezone info are interpreted as the local timezone,
    as this was the behavior in earlier versions.
- Update to 4.4.0
  * Add :meth:`.KernelClient.load_connection_info` on KernelClient, etc. for loading connection info
    directly from a dict, not just from files.
  * Include parent headers when adapting messages from older protocol implementations
    (treats parent headers the same as headers).
  * Compatibility fixes in tests for recent changes in ipykernel.
- Update to 4.3.0
  * Adds ``--sys-prefix`` argument to :command:`jupyter kernelspec install`,
    for better symmetry with :command:`jupyter nbextension install`, etc.
- Update to 4.2.2
  * Another fix for the :func:`start_new_kernel` issue in 4.2.1 affecting slow-starting kernels.
- Update to 4.2.1
  * Fix regression in 4.2 causing :func:`start_new_kernel`
    to fail while waiting for kernels to become available.
- Update to 4.2.0
  * added :command:`jupyter kernelspec remove` for removing kernelspecs
  * allow specifying the environment for kernel processes via the ``env`` argument
  * added ``name`` field to connection files identifying the kernelspec name,
    so that consumers of connection files (alternate frontends) can identify the kernelspec in use
  * added :meth:`KernelSpecManager.get_all_specs` for getting all kernelspecs more efficiently
  * various improvements to error messages and documentation
- Split documentation into own subpackage
* Mon Oct 12 2015 toddrme2178@gmail.com
- update to version 4.1.1:
  * Setuptools fixes for jupyter kernelspec
  * jupyter kernelspec list includes paths
  * add :meth:`KernelManager.blocking_client`
  * provisional implementation of comm_info requests from upcoming 5.1
    release of the protocol
* Thu Oct  1 2015 toddrme2178@gmail.com
- Build documentation
* Fri Aug 14 2015 toddrme2178@gmail.com
- Fix update-alternatives usage
* Tue Jul 21 2015 toddrme2178@gmail.com
- Initial version
